from bvs_mapping import make_map

# Fill in the variables below with values for your system

# NECESSARY - you must choose an input structure file, and the grid spacing
#
# filename - The structure file containing the cell and atomic positions
#            for the crystal structure to be mapped. Must be a readable
#            format by ase.
filename = "example.cif"

# spacing - The grid spacing in Angstroms to draw the BVS map onto
spacing = 0.2

# OPTIONAL - You might be able to rely on default values from here
#
# r0_iO - The bond valence sum parameter for the atom of interest with 
#         oxygen (N.B. oxygen is the only anion currently available).
#         Default: 1.466 Angstroms, for Li-O
r0_iO = 1.466 
# rho - The bond valence sum parameter in the denominator
rho=0.37
# cutoff - Cutoff of atom-atom distances for bond valence sum
cutoff=2.
# center - The point on which the origin of the grid is positioned
#          Default: [0.,0.,0.]
center=[0.,0.,0.]
# base_name - The basis of the output filename for the map
#             Default: "BVS_charges"
base_name="BVS_charges"
# output - The output format. Currently available options are:
#          "grd" - VESTA periodic grid format (default)
#          "cube" - Gaussian cube format
#          If these options are not present then the map will not be 
#          written to file
output="grd"
# limits - The upper and lower limits of the map data to print out.
#          Default: None - no limits are set
#          The limits object should be a list object containing floats
#          for the lower and then upper limits
#             e.g. [0.7,1.3] 
limits=None
# ideal_valence - If the ideal valence is specified, then the absolute
#                 difference from this value (the BV mismatch 
#                 Adams, J. Power Sources, 159 (2006) 200) is calculated
#                 and written out along with the BVS map
ideal_valence=None
# maximum - Instead of outputting the BV mismatch, the function 
#           ideal_valence - mismatch is output, which should have maxima 
#           when the BVS is close to ideal.
maximum=False
# counter_ion - Counter ion for BVS calculations. Default is oxygen
counter_ion="O"
# penalty - If set then the penalty function defined in Adams, Solid State
#           Ionics, 177 (2006) 1625 is calculated. Set the variable penalty
#           to the ratio of the ideal valence and the minimum coordination 
#           number.
penalty=None
# com - There is also the option to calculate the distance of the local 
#       center of mass of coordinated counter ions from the position. To 
#       use this option set com to the cutoff in Angstroms for the 
#       coordination sphere.
com=None
# min_coord - If the coordination sphere used for calculation of the local
#             center of mass contains fewer coordinating atoms than this 
#             value, then com is returned as a large number (default 1E6)
min_coord=1

make_map(filename,spacing,r0_iO=r0_iO,rho=rho,cutoff=cutoff,center=center,
         base_name=base_name,output=output,penalty=penalty,com=com,
         min_coord=min_coord,
         limits=limits,ideal_valence=ideal_valence,maximum=maximum,
         counter_ion=counter_ion)
